PCB Environment: util Namespace Reference

PCB Environment 2

Loading...
Searching...
No Matches
Functions
util Namespace Reference

## Functions
void | populate (std::set< Connection * > &, PCBoard &, PyObject *)
void | populate (std::set< Net * > &, PCBoard &, PyObject *)
void | populate (std::set< Component * > &, PCBoard &, PyObject *)
void | populate (std::set< Pin * > &, PCBoard &, PyObject *)
bool | lexiconumeric_compare (const std::string &, const std::string &)
std::string | loadFile (const std::string &filePath)
std::string | loadFile (const std::string_view filePath)
std::string | tolower (const std::string &)
bool | is1TrueYesOrPlus (const char *)
bool | is1TrueYesOrPlus (const std::string &s)

## Function Documentation

## ◆ is1TrueYesOrPlus() [1/2]

bool util::is1TrueYesOrPlus | ( | const char * |  | ) |

## ◆ is1TrueYesOrPlus() [2/2]

bool util::is1TrueYesOrPlus | ( | const std::string & | s | ) |
| inline

## ◆ lexiconumeric_compare()

bool util::lexiconumeric_compare | ( | const std::string & | ,
|  | const std::string & | )

## ◆ loadFile() [1/2]

std::string util::loadFile | ( | const std::string & | filePath | ) |

## ◆ loadFile() [2/2]

std::string util::loadFile | ( | const std::string_view | filePath | ) |
| inline

## ◆ populate() [1/4]

void util::populate | ( | std::set< Component * > & | ,
|  | PCBoard & | ,
|  | PyObject * | )

## ◆ populate() [2/4]

void util::populate | ( | std::set< Connection * > & | ,
|  | PCBoard & | ,
|  | PyObject * | )

## ◆ populate() [3/4]

void util::populate | ( | std::set< Net * > & | ,
|  | PCBoard & | ,
|  | PyObject * | )

## ◆ populate() [4/4]

void util::populate | ( | std::set< Pin * > & | ,
|  | PCBoard & | ,
|  | PyObject * | )

## ◆ tolower()

std::string util::tolower | ( | const std::string & |  | ) |